<template>
  <el-dialog v-dialogDrag
             :append-to-body="true"
             :close-on-click-modal="false"
             :destroy-on-close="true"
             :title="dialog.title"
             :visible.sync="dialog.showDialog"
             class="avue-dialog"
             width="1200px"
             @close="cancelDialog">
    <el-container style="height: 580px">
      <el-aside style="width: 380px">
        <basic-container v-loading="leftLoading" style="height: 530px">
          <div style="height: 435px">
            <avue-tree ref="tree" :data="treeData" :option="treeOption" @node-click="nodeClick">
              <span slot-scope="{ node, data }" class="el-tree-node__label">
               <span>
                 <icon-show :name="data.icon"></icon-show>
                    {{ (node || {}).label }}
                </span>
              </span>
            </avue-tree>
          </div>
        </basic-container>
      </el-aside>

      <el-main>
        <basic-container v-loading="rightLoading" style="height: 530px">
          <div style="height: 490px;">
            <avue-tree ref="uiTree" :data="uiTreeData" :option="uiTreeOption" @check-change="checkChange">
              <span slot-scope="{ node, data }" class="el-tree-node__label">
                <span>
                  <i :class="data.icon"></i>
                    {{ (node || {}).label }}
                </span>
              </span>
            </avue-tree>
          </div>
        </basic-container>
      </el-main>
    </el-container>
    <div class="dialog-footer avue-dialog__footer">
      <el-button size="small" type="primary" @click="submitDialog">保 存</el-button>
      <el-button size="small" @click="cancelDialog">取 消</el-button>
    </div>
  </el-dialog>
</template>

<script>
import {getBizTree, getAllLevelTreeByBtm, clonePageDef, clonetabPage, cloneTabButton} from "@/api/UI/uiDefine";

export default {
  name: "cloneDialog",
  props: ['fromOid', 'type', 'sourceOId','paramsType'],
  data() {
    return {
      leftLoading: false,
      rightLoading: false,
      dialog: {
        showDialog: false,
        title: "克隆目标",
        loading: false,
        type: "clone",
      },
      treeOption: {
        menu: false,
        addBtn: false,
        defaultExpandAll:true,
        props: {
          label: 'text',
          value: 'oid',
          children: 'children'
        }
      },
      nodeRow: {},
      treeData: [],
      defaultExpandKeys: [],
      uiTreeOption: {
        nodeKey: 'oid',
        checkOnClickNode: true,
        defaultExpandAll:true,
        //defaultExpandedKeys: this.defaultExpandKeys,
        multiple: false,
        menu: false,
        addBtn: false,
        filter: false,
        props: {
          label: 'text',
          value: 'oid',
          children: 'children'
        }
      },
      uiTreeData: [],
    };
  },
  methods: {
    openDialog(data) {
      this.dialog.showDialog = true;
      this.getTreeList()
      this.uiTreeData = [];
    },
    cancelDialog() {
      this.dialog.loading = false;
      this.dialog.showDialog = false;
    },
    submitDialog() {
      const node = this.$refs.uiTree.getCurrentNode();
      if (!node.leaf) {
        this.$message.error('请选择最下层子节点进行克隆');
        return;
      }
      let params = {};
      if (node) {
        params = {
          fromOid: this.fromOid,
          toOid: node.oid,
          cloneParam: {
            sourceOId: this.sourceOId
          }
        }
      }
      console.log(params);
      const saveFunction = {
        'pageDef': clonePageDef,
        'tabPage': clonetabPage,
        'tabButton': cloneTabButton
      };
      saveFunction[this.type](params).then(res => {
        if(res.data.code == 200){
          this.$message.success(res.data.obj);
          this.cancelDialog();
        }
      })
    },
    getTreeList() {
      this.leftLoading = true;
      getBizTree().then(res => {
        this.treeData = [{
          attributes: {},
          checked: false,
          expanded: true,
          data: "root",
          level: res.data.obj.level,
          icon: 'vci:home',
          oid: res.data.obj.oid,
          text: res.data.obj.text,
          children: res.data.obj.children
        }] ;
        this.leftLoading = false;
      }).catch(error => {
        this.leftLoading = false;
      })
    },
    // 角色点击
    nodeClick(row, node) {
      if(row.oid==''){
        return false;
      }
      this.nodeRow = row;
      this.rightLoading = true;
      const params = {
        btmName: this.nodeRow.attributes.name,
        level: this.paramsType
      }
      //this.defaultExpandKeys = ['UILayout'];
      getAllLevelTreeByBtm(params).then(res => {
        //this.defaultExpandedKeys = [res.data.obj.oid];
        res.data.obj.icon='el-icon-s-home';
        let level=0;
        this.processChildren(res.data.obj,level); // 处理每个节点
        //this.uiTreeOption.defaultExpandedKeys = this.defaultExpandKeys;
        this.uiTreeData = [res.data.obj];
        this.rightLoading = false;
      }).catch(error => {
        this.rightLoading = false;
      })
    },

    //处理树
    processChildren(item,level) {
      if (item.children && item.children.length > 0) {
        level++;
        item.children = item.children.map(child => {
          if (child.level < 4) {
            //this.defaultExpandKeys.push(child.oid)
          }
          if (level == 1) {
            child.icon = 'el-icon-s-promotion';
          } else if (level == 2) {
            child.icon = 'el-icon-s-order';
          } else if (level == 3) {
            child.icon = 'el-icon-office-building';
          } else if (level == 4) {
            child.icon = 'el-icon-document';
          } else if (level == 5) {
            child.icon = 'el-icon-s-tools';
          }
          this.processChildren(child,level); // 递归处理每个子节点
          return child; // 只返回子节点的 attributes
        });
      }
    },
  },
}
</script>

<style scoped>

</style>
